# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/datacatalog_v1beta1/proto/datacatalog.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.datacatalog_v1beta1.proto import (
    common_pb2 as google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_common__pb2,
)
from google.cloud.datacatalog_v1beta1.proto import (
    gcs_fileset_spec_pb2 as google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_gcs__fileset__spec__pb2,
)
from google.cloud.datacatalog_v1beta1.proto import (
    schema_pb2 as google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_schema__pb2,
)
from google.cloud.datacatalog_v1beta1.proto import (
    search_pb2 as google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_search__pb2,
)
from google.cloud.datacatalog_v1beta1.proto import (
    table_spec_pb2 as google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_table__spec__pb2,
)
from google.cloud.datacatalog_v1beta1.proto import (
    tags_pb2 as google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2,
)
from google.cloud.datacatalog_v1beta1.proto import (
    timestamps_pb2 as google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_timestamps__pb2,
)
from google.iam.v1 import iam_policy_pb2 as google_dot_iam_dot_v1_dot_iam__policy__pb2
from google.iam.v1 import policy_pb2 as google_dot_iam_dot_v1_dot_policy__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/datacatalog_v1beta1/proto/datacatalog.proto",
    package="google.cloud.datacatalog.v1beta1",
    syntax="proto3",
    serialized_options=b"\n$com.google.cloud.datacatalog.v1beta1P\001ZKgoogle.golang.org/genproto/googleapis/cloud/datacatalog/v1beta1;datacatalog\370\001\001\252\002 Google.Cloud.DataCatalog.V1Beta1\312\002 Google\\Cloud\\DataCatalog\\V1beta1\352\002#Google::Cloud::DataCatalog::V1beta1",
    serialized_pb=b'\n8google/cloud/datacatalog_v1beta1/proto/datacatalog.proto\x12 google.cloud.datacatalog.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x33google/cloud/datacatalog_v1beta1/proto/common.proto\x1a=google/cloud/datacatalog_v1beta1/proto/gcs_fileset_spec.proto\x1a\x33google/cloud/datacatalog_v1beta1/proto/schema.proto\x1a\x33google/cloud/datacatalog_v1beta1/proto/search.proto\x1a\x37google/cloud/datacatalog_v1beta1/proto/table_spec.proto\x1a\x31google/cloud/datacatalog_v1beta1/proto/tags.proto\x1a\x37google/cloud/datacatalog_v1beta1/proto/timestamps.proto\x1a\x1egoogle/iam/v1/iam_policy.proto\x1a\x1agoogle/iam/v1/policy.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto"\x9e\x02\n\x14SearchCatalogRequest\x12P\n\x05scope\x18\x06 \x01(\x0b\x32<.google.cloud.datacatalog.v1beta1.SearchCatalogRequest.ScopeB\x03\xe0\x41\x02\x12\x12\n\x05query\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a\x62\n\x05Scope\x12\x17\n\x0finclude_org_ids\x18\x02 \x03(\t\x12\x1b\n\x13include_project_ids\x18\x03 \x03(\t\x12#\n\x1binclude_gcp_public_datasets\x18\x07 \x01(\x08"x\n\x15SearchCatalogResponse\x12\x46\n\x07results\x18\x01 \x03(\x0b\x32\x35.google.cloud.datacatalog.v1beta1.SearchCatalogResult\x12\x17\n\x0fnext_page_token\x18\x03 \x01(\t"\xb8\x01\n\x17\x43reateEntryGroupRequest\x12=\n\x06parent\x18\x01 \x01(\tB-\xe0\x41\x02\xfa\x41\'\x12%datacatalog.googleapis.com/EntryGroup\x12\x1b\n\x0e\x65ntry_group_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\x12\x41\n\x0b\x65ntry_group\x18\x02 \x01(\x0b\x32,.google.cloud.datacatalog.v1beta1.EntryGroup"\x92\x01\n\x17UpdateEntryGroupRequest\x12\x46\n\x0b\x65ntry_group\x18\x01 \x01(\x0b\x32,.google.cloud.datacatalog.v1beta1.EntryGroupB\x03\xe0\x41\x02\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"\x82\x01\n\x14GetEntryGroupRequest\x12;\n\x04name\x18\x01 \x01(\tB-\xe0\x41\x02\xfa\x41\'\n%datacatalog.googleapis.com/EntryGroup\x12-\n\tread_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"j\n\x17\x44\x65leteEntryGroupRequest\x12;\n\x04name\x18\x01 \x01(\tB-\xe0\x41\x02\xfa\x41\'\n%datacatalog.googleapis.com/EntryGroup\x12\x12\n\x05\x66orce\x18\x02 \x01(\x08\x42\x03\xe0\x41\x01"\x88\x01\n\x16ListEntryGroupsRequest\x12=\n\x06parent\x18\x01 \x01(\tB-\xe0\x41\x02\xfa\x41\'\n%datacatalog.googleapis.com/EntryGroup\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01"v\n\x17ListEntryGroupsResponse\x12\x42\n\x0c\x65ntry_groups\x18\x01 \x03(\x0b\x32,.google.cloud.datacatalog.v1beta1.EntryGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"\xa7\x01\n\x12\x43reateEntryRequest\x12=\n\x06parent\x18\x01 \x01(\tB-\xe0\x41\x02\xfa\x41\'\n%datacatalog.googleapis.com/EntryGroup\x12\x15\n\x08\x65ntry_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\x12;\n\x05\x65ntry\x18\x02 \x01(\x0b\x32\'.google.cloud.datacatalog.v1beta1.EntryB\x03\xe0\x41\x02"\x82\x01\n\x12UpdateEntryRequest\x12;\n\x05\x65ntry\x18\x01 \x01(\x0b\x32\'.google.cloud.datacatalog.v1beta1.EntryB\x03\xe0\x41\x02\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"L\n\x12\x44\x65leteEntryRequest\x12\x36\n\x04name\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41"\n datacatalog.googleapis.com/Entry"I\n\x0fGetEntryRequest\x12\x36\n\x04name\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41"\n datacatalog.googleapis.com/Entry"V\n\x12LookupEntryRequest\x12\x19\n\x0flinked_resource\x18\x01 \x01(\tH\x00\x12\x16\n\x0csql_resource\x18\x03 \x01(\tH\x00\x42\r\n\x0btarget_name"\x8f\x07\n\x05\x45ntry\x12\x38\n\x04name\x18\x01 \x01(\tB*\xfa\x41\'\n%datacatalog.googleapis.com/EntryGroup\x12\x17\n\x0flinked_resource\x18\t \x01(\t\x12;\n\x04type\x18\x02 \x01(\x0e\x32+.google.cloud.datacatalog.v1beta1.EntryTypeH\x00\x12\x1d\n\x13user_specified_type\x18\x10 \x01(\tH\x00\x12T\n\x11integrated_system\x18\x11 \x01(\x0e\x32\x32.google.cloud.datacatalog.v1beta1.IntegratedSystemB\x03\xe0\x41\x03H\x01\x12\x1f\n\x15user_specified_system\x18\x12 \x01(\tH\x01\x12L\n\x10gcs_fileset_spec\x18\x06 \x01(\x0b\x32\x30.google.cloud.datacatalog.v1beta1.GcsFilesetSpecH\x02\x12R\n\x13\x62igquery_table_spec\x18\x0c \x01(\x0b\x32\x33.google.cloud.datacatalog.v1beta1.BigQueryTableSpecH\x02\x12_\n\x1a\x62igquery_date_sharded_spec\x18\x0f \x01(\x0b\x32\x39.google.cloud.datacatalog.v1beta1.BigQueryDateShardedSpecH\x02\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x38\n\x06schema\x18\x05 \x01(\x0b\x32(.google.cloud.datacatalog.v1beta1.Schema\x12Y\n\x18source_system_timestamps\x18\x07 \x01(\x0b\x32\x32.google.cloud.datacatalog.v1beta1.SystemTimestampsB\x03\xe0\x41\x03:x\xea\x41u\n datacatalog.googleapis.com/Entry\x12Qprojects/{project}/locations/{location}/entryGroups/{entry_group}/entries/{entry}B\x0c\n\nentry_typeB\x08\n\x06systemB\x0b\n\ttype_spec"\x8e\x02\n\nEntryGroup\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12X\n\x17\x64\x61ta_catalog_timestamps\x18\x04 \x01(\x0b\x32\x32.google.cloud.datacatalog.v1beta1.SystemTimestampsB\x03\xe0\x41\x03:m\xea\x41j\n%datacatalog.googleapis.com/EntryGroup\x12\x41projects/{project}/locations/{location}/entryGroups/{entry_group}"\xc2\x01\n\x18\x43reateTagTemplateRequest\x12>\n\x06parent\x18\x01 \x01(\tB.\xe0\x41\x02\xfa\x41(\x12&datacatalog.googleapis.com/TagTemplate\x12\x1c\n\x0ftag_template_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\x12H\n\x0ctag_template\x18\x02 \x01(\x0b\x32-.google.cloud.datacatalog.v1beta1.TagTemplateB\x03\xe0\x41\x02"U\n\x15GetTagTemplateRequest\x12<\n\x04name\x18\x01 \x01(\tB.\xe0\x41\x02\xfa\x41(\n&datacatalog.googleapis.com/TagTemplate"\x95\x01\n\x18UpdateTagTemplateRequest\x12H\n\x0ctag_template\x18\x01 \x01(\x0b\x32-.google.cloud.datacatalog.v1beta1.TagTemplateB\x03\xe0\x41\x02\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"l\n\x18\x44\x65leteTagTemplateRequest\x12<\n\x04name\x18\x01 \x01(\tB.\xe0\x41\x02\xfa\x41(\n&datacatalog.googleapis.com/TagTemplate\x12\x12\n\x05\x66orce\x18\x02 \x01(\x08\x42\x03\xe0\x41\x02"\x83\x01\n\x10\x43reateTagRequest\x12\x36\n\x06parent\x18\x01 \x01(\tB&\xe0\x41\x02\xfa\x41 \n\x1e\x64\x61tacatalog.googleapis.com/Tag\x12\x37\n\x03tag\x18\x02 \x01(\x0b\x32%.google.cloud.datacatalog.v1beta1.TagB\x03\xe0\x41\x02"|\n\x10UpdateTagRequest\x12\x37\n\x03tag\x18\x01 \x01(\x0b\x32%.google.cloud.datacatalog.v1beta1.TagB\x03\xe0\x41\x02\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"H\n\x10\x44\x65leteTagRequest\x12\x34\n\x04name\x18\x01 \x01(\tB&\xe0\x41\x02\xfa\x41 \x12\x1e\x64\x61tacatalog.googleapis.com/Tag"\xd8\x01\n\x1d\x43reateTagTemplateFieldRequest\x12>\n\x06parent\x18\x01 \x01(\tB.\xe0\x41\x02\xfa\x41(\n&datacatalog.googleapis.com/TagTemplate\x12"\n\x15tag_template_field_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12S\n\x12tag_template_field\x18\x03 \x01(\x0b\x32\x32.google.cloud.datacatalog.v1beta1.TagTemplateFieldB\x03\xe0\x41\x02"\xed\x01\n\x1dUpdateTagTemplateFieldRequest\x12\x41\n\x04name\x18\x01 \x01(\tB3\xe0\x41\x02\xfa\x41-\n+datacatalog.googleapis.com/TagTemplateField\x12S\n\x12tag_template_field\x18\x02 \x01(\x0b\x32\x32.google.cloud.datacatalog.v1beta1.TagTemplateFieldB\x03\xe0\x41\x02\x12\x34\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x01"\x8a\x01\n\x1dRenameTagTemplateFieldRequest\x12\x41\n\x04name\x18\x01 \x01(\tB3\xe0\x41\x02\xfa\x41-\n+datacatalog.googleapis.com/TagTemplateField\x12&\n\x19new_tag_template_field_id\x18\x02 \x01(\tB\x03\xe0\x41\x02"v\n\x1d\x44\x65leteTagTemplateFieldRequest\x12\x41\n\x04name\x18\x01 \x01(\tB3\xe0\x41\x02\xfa\x41-\n+datacatalog.googleapis.com/TagTemplateField\x12\x12\n\x05\x66orce\x18\x02 \x01(\x08\x42\x03\xe0\x41\x02"p\n\x0fListTagsRequest\x12\x36\n\x06parent\x18\x01 \x01(\tB&\xe0\x41\x02\xfa\x41 \x12\x1e\x64\x61tacatalog.googleapis.com/Tag\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t"`\n\x10ListTagsResponse\x12\x33\n\x04tags\x18\x01 \x03(\x0b\x32%.google.cloud.datacatalog.v1beta1.Tag\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"\xa9\x01\n\x12ListEntriesRequest\x12=\n\x06parent\x18\x01 \x01(\tB-\xe0\x41\x02\xfa\x41\'\n%datacatalog.googleapis.com/EntryGroup\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\x12-\n\tread_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"h\n\x13ListEntriesResponse\x12\x38\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\'.google.cloud.datacatalog.v1beta1.Entry\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t*[\n\tEntryType\x12\x1a\n\x16\x45NTRY_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05TABLE\x10\x02\x12\t\n\x05MODEL\x10\x05\x12\x0f\n\x0b\x44\x41TA_STREAM\x10\x03\x12\x0b\n\x07\x46ILESET\x10\x04\x32\xbc\x32\n\x0b\x44\x61taCatalog\x12\xb2\x01\n\rSearchCatalog\x12\x36.google.cloud.datacatalog.v1beta1.SearchCatalogRequest\x1a\x37.google.cloud.datacatalog.v1beta1.SearchCatalogResponse"0\x82\xd3\xe4\x93\x02\x1c"\x17/v1beta1/catalog:search:\x01*\xda\x41\x0bscope,query\x12\xea\x01\n\x10\x43reateEntryGroup\x12\x39.google.cloud.datacatalog.v1beta1.CreateEntryGroupRequest\x1a,.google.cloud.datacatalog.v1beta1.EntryGroup"m\x82\xd3\xe4\x93\x02\x43"4/v1beta1/{parent=projects/*/locations/*}/entryGroups:\x0b\x65ntry_group\xda\x41!parent,entry_group_id,entry_group\x12\xfa\x01\n\x10UpdateEntryGroup\x12\x39.google.cloud.datacatalog.v1beta1.UpdateEntryGroupRequest\x1a,.google.cloud.datacatalog.v1beta1.EntryGroup"}\x82\xd3\xe4\x93\x02O2@/v1beta1/{entry_group.name=projects/*/locations/*/entryGroups/*}:\x0b\x65ntry_group\xda\x41\x0b\x65ntry_group\xda\x41\x17\x65ntry_group,update_mask\x12\xcb\x01\n\rGetEntryGroup\x12\x36.google.cloud.datacatalog.v1beta1.GetEntryGroupRequest\x1a,.google.cloud.datacatalog.v1beta1.EntryGroup"T\x82\xd3\xe4\x93\x02\x36\x12\x34/v1beta1/{name=projects/*/locations/*/entryGroups/*}\xda\x41\x04name\xda\x41\x0ename,read_mask\x12\xaa\x01\n\x10\x44\x65leteEntryGroup\x12\x39.google.cloud.datacatalog.v1beta1.DeleteEntryGroupRequest\x1a\x16.google.protobuf.Empty"C\x82\xd3\xe4\x93\x02\x36*4/v1beta1/{name=projects/*/locations/*/entryGroups/*}\xda\x41\x04name\x12\xcd\x01\n\x0fListEntryGroups\x12\x38.google.cloud.datacatalog.v1beta1.ListEntryGroupsRequest\x1a\x39.google.cloud.datacatalog.v1beta1.ListEntryGroupsResponse"E\x82\xd3\xe4\x93\x02\x36\x12\x34/v1beta1/{parent=projects/*/locations/*}/entryGroups\xda\x41\x06parent\x12\xd3\x01\n\x0b\x43reateEntry\x12\x34.google.cloud.datacatalog.v1beta1.CreateEntryRequest\x1a\'.google.cloud.datacatalog.v1beta1.Entry"e\x82\xd3\xe4\x93\x02G">/v1beta1/{parent=projects/*/locations/*/entryGroups/*}/entries:\x05\x65ntry\xda\x41\x15parent,entry_id,entry\x12\xdd\x01\n\x0bUpdateEntry\x12\x34.google.cloud.datacatalog.v1beta1.UpdateEntryRequest\x1a\'.google.cloud.datacatalog.v1beta1.Entry"o\x82\xd3\xe4\x93\x02M2D/v1beta1/{entry.name=projects/*/locations/*/entryGroups/*/entries/*}:\x05\x65ntry\xda\x41\x05\x65ntry\xda\x41\x11\x65ntry,update_mask\x12\xaa\x01\n\x0b\x44\x65leteEntry\x12\x34.google.cloud.datacatalog.v1beta1.DeleteEntryRequest\x1a\x16.google.protobuf.Empty"M\x82\xd3\xe4\x93\x02@*>/v1beta1/{name=projects/*/locations/*/entryGroups/*/entries/*}\xda\x41\x04name\x12\xb5\x01\n\x08GetEntry\x12\x31.google.cloud.datacatalog.v1beta1.GetEntryRequest\x1a\'.google.cloud.datacatalog.v1beta1.Entry"M\x82\xd3\xe4\x93\x02@\x12>/v1beta1/{name=projects/*/locations/*/entryGroups/*/entries/*}\xda\x41\x04name\x12\x8d\x01\n\x0bLookupEntry\x12\x34.google.cloud.datacatalog.v1beta1.LookupEntryRequest\x1a\'.google.cloud.datacatalog.v1beta1.Entry"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1beta1/entries:lookup\x12\xcb\x01\n\x0bListEntries\x12\x34.google.cloud.datacatalog.v1beta1.ListEntriesRequest\x1a\x35.google.cloud.datacatalog.v1beta1.ListEntriesResponse"O\x82\xd3\xe4\x93\x02@\x12>/v1beta1/{parent=projects/*/locations/*/entryGroups/*}/entries\xda\x41\x06parent\x12\xf1\x01\n\x11\x43reateTagTemplate\x12:.google.cloud.datacatalog.v1beta1.CreateTagTemplateRequest\x1a-.google.cloud.datacatalog.v1beta1.TagTemplate"q\x82\xd3\xe4\x93\x02\x45"5/v1beta1/{parent=projects/*/locations/*}/tagTemplates:\x0ctag_template\xda\x41#parent,tag_template_id,tag_template\x12\xbe\x01\n\x0eGetTagTemplate\x12\x37.google.cloud.datacatalog.v1beta1.GetTagTemplateRequest\x1a-.google.cloud.datacatalog.v1beta1.TagTemplate"D\x82\xd3\xe4\x93\x02\x37\x12\x35/v1beta1/{name=projects/*/locations/*/tagTemplates/*}\xda\x41\x04name\x12\x83\x02\n\x11UpdateTagTemplate\x12:.google.cloud.datacatalog.v1beta1.UpdateTagTemplateRequest\x1a-.google.cloud.datacatalog.v1beta1.TagTemplate"\x82\x01\x82\xd3\xe4\x93\x02R2B/v1beta1/{tag_template.name=projects/*/locations/*/tagTemplates/*}:\x0ctag_template\xda\x41\x0ctag_template\xda\x41\x18tag_template,update_mask\x12\xb3\x01\n\x11\x44\x65leteTagTemplate\x12:.google.cloud.datacatalog.v1beta1.DeleteTagTemplateRequest\x1a\x16.google.protobuf.Empty"J\x82\xd3\xe4\x93\x02\x37*5/v1beta1/{name=projects/*/locations/*/tagTemplates/*}\xda\x41\nname,force\x12\x9c\x02\n\x16\x43reateTagTemplateField\x12?.google.cloud.datacatalog.v1beta1.CreateTagTemplateFieldRequest\x1a\x32.google.cloud.datacatalog.v1beta1.TagTemplateField"\x8c\x01\x82\xd3\xe4\x93\x02T">/v1beta1/{parent=projects/*/locations/*/tagTemplates/*}/fields:\x12tag_template_field\xda\x41/parent,tag_template_field_id,tag_template_field\x12\xaa\x02\n\x16UpdateTagTemplateField\x12?.google.cloud.datacatalog.v1beta1.UpdateTagTemplateFieldRequest\x1a\x32.google.cloud.datacatalog.v1beta1.TagTemplateField"\x9a\x01\x82\xd3\xe4\x93\x02T2>/v1beta1/{name=projects/*/locations/*/tagTemplates/*/fields/*}:\x12tag_template_field\xda\x41\x17name,tag_template_field\xda\x41#name,tag_template_field,update_mask\x12\x80\x02\n\x16RenameTagTemplateField\x12?.google.cloud.datacatalog.v1beta1.RenameTagTemplateFieldRequest\x1a\x32.google.cloud.datacatalog.v1beta1.TagTemplateField"q\x82\xd3\xe4\x93\x02J"E/v1beta1/{name=projects/*/locations/*/tagTemplates/*/fields/*}:rename:\x01*\xda\x41\x1ename,new_tag_template_field_id\x12\xc6\x01\n\x16\x44\x65leteTagTemplateField\x12?.google.cloud.datacatalog.v1beta1.DeleteTagTemplateFieldRequest\x1a\x16.google.protobuf.Empty"S\x82\xd3\xe4\x93\x02@*>/v1beta1/{name=projects/*/locations/*/tagTemplates/*/fields/*}\xda\x41\nname,force\x12\x8d\x02\n\tCreateTag\x12\x32.google.cloud.datacatalog.v1beta1.CreateTagRequest\x1a%.google.cloud.datacatalog.v1beta1.Tag"\xa4\x01\x82\xd3\xe4\x93\x02\x90\x01"E/v1beta1/{parent=projects/*/locations/*/entryGroups/*/entries/*}/tags:\x03tagZB";/v1beta1/{parent=projects/*/locations/*/entryGroups/*}/tags:\x03tag\xda\x41\nparent,tag\x12\xa0\x02\n\tUpdateTag\x12\x32.google.cloud.datacatalog.v1beta1.UpdateTagRequest\x1a%.google.cloud.datacatalog.v1beta1.Tag"\xb7\x01\x82\xd3\xe4\x93\x02\x98\x01\x32I/v1beta1/{tag.name=projects/*/locations/*/entryGroups/*/entries/*/tags/*}:\x03tagZF2?/v1beta1/{tag.name=projects/*/locations/*/entryGroups/*/tags/*}:\x03tag\xda\x41\x03tag\xda\x41\x0ftag,update_mask\x12\xee\x01\n\tDeleteTag\x12\x32.google.cloud.datacatalog.v1beta1.DeleteTagRequest\x1a\x16.google.protobuf.Empty"\x94\x01\x82\xd3\xe4\x93\x02\x86\x01*E/v1beta1/{name=projects/*/locations/*/entryGroups/*/entries/*/tags/*}Z=*;/v1beta1/{name=projects/*/locations/*/entryGroups/*/tags/*}\xda\x41\x04name\x12\x8a\x02\n\x08ListTags\x12\x31.google.cloud.datacatalog.v1beta1.ListTagsRequest\x1a\x32.google.cloud.datacatalog.v1beta1.ListTagsResponse"\x96\x01\x82\xd3\xe4\x93\x02\x86\x01\x12\x45/v1beta1/{parent=projects/*/locations/*/entryGroups/*/entries/*}/tagsZ=\x12;/v1beta1/{parent=projects/*/locations/*/entryGroups/*}/tags\xda\x41\x06parent\x12\xfc\x01\n\x0cSetIamPolicy\x12".google.iam.v1.SetIamPolicyRequest\x1a\x15.google.iam.v1.Policy"\xb0\x01\x82\xd3\xe4\x93\x02\x97\x01"F/v1beta1/{resource=projects/*/locations/*/tagTemplates/*}:setIamPolicy:\x01*ZJ"E/v1beta1/{resource=projects/*/locations/*/entryGroups/*}:setIamPolicy:\x01*\xda\x41\x0fresource,policy\x12\xcb\x02\n\x0cGetIamPolicy\x12".google.iam.v1.GetIamPolicyRequest\x1a\x15.google.iam.v1.Policy"\xff\x01\x82\xd3\xe4\x93\x02\xed\x01"F/v1beta1/{resource=projects/*/locations/*/tagTemplates/*}:getIamPolicy:\x01*ZJ"E/v1beta1/{resource=projects/*/locations/*/entryGroups/*}:getIamPolicy:\x01*ZT"O/v1beta1/{resource=projects/*/locations/*/entryGroups/*/entries/*}:getIamPolicy:\x01*\xda\x41\x08resource\x12\xf2\x02\n\x12TestIamPermissions\x12(.google.iam.v1.TestIamPermissionsRequest\x1a).google.iam.v1.TestIamPermissionsResponse"\x86\x02\x82\xd3\xe4\x93\x02\xff\x01"L/v1beta1/{resource=projects/*/locations/*/tagTemplates/*}:testIamPermissions:\x01*ZP"K/v1beta1/{resource=projects/*/locations/*/entryGroups/*}:testIamPermissions:\x01*ZZ"U/v1beta1/{resource=projects/*/locations/*/entryGroups/*/entries/*}:testIamPermissions:\x01*\x1aN\xca\x41\x1a\x64\x61tacatalog.googleapis.com\xd2\x41.https://www.googleapis.com/auth/cloud-platformB\xe4\x01\n$com.google.cloud.datacatalog.v1beta1P\x01ZKgoogle.golang.org/genproto/googleapis/cloud/datacatalog/v1beta1;datacatalog\xf8\x01\x01\xaa\x02 Google.Cloud.DataCatalog.V1Beta1\xca\x02 Google\\Cloud\\DataCatalog\\V1beta1\xea\x02#Google::Cloud::DataCatalog::V1beta1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_common__pb2.DESCRIPTOR,
        google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_gcs__fileset__spec__pb2.DESCRIPTOR,
        google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_schema__pb2.DESCRIPTOR,
        google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_search__pb2.DESCRIPTOR,
        google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_table__spec__pb2.DESCRIPTOR,
        google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.DESCRIPTOR,
        google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_timestamps__pb2.DESCRIPTOR,
        google_dot_iam_dot_v1_dot_iam__policy__pb2.DESCRIPTOR,
        google_dot_iam_dot_v1_dot_policy__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
    ],
)

_ENTRYTYPE = _descriptor.EnumDescriptor(
    name="EntryType",
    full_name="google.cloud.datacatalog.v1beta1.EntryType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="ENTRY_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="TABLE", index=1, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="MODEL", index=2, number=5, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="DATA_STREAM", index=3, number=3, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="FILESET", index=4, number=4, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=5787,
    serialized_end=5878,
)
_sym_db.RegisterEnumDescriptor(_ENTRYTYPE)

EntryType = enum_type_wrapper.EnumTypeWrapper(_ENTRYTYPE)
ENTRY_TYPE_UNSPECIFIED = 0
TABLE = 2
MODEL = 5
DATA_STREAM = 3
FILESET = 4


_SEARCHCATALOGREQUEST_SCOPE = _descriptor.Descriptor(
    name="Scope",
    full_name="google.cloud.datacatalog.v1beta1.SearchCatalogRequest.Scope",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="include_org_ids",
            full_name="google.cloud.datacatalog.v1beta1.SearchCatalogRequest.Scope.include_org_ids",
            index=0,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="include_project_ids",
            full_name="google.cloud.datacatalog.v1beta1.SearchCatalogRequest.Scope.include_project_ids",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="include_gcp_public_datasets",
            full_name="google.cloud.datacatalog.v1beta1.SearchCatalogRequest.Scope.include_gcp_public_datasets",
            index=2,
            number=7,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=908,
    serialized_end=1006,
)

_SEARCHCATALOGREQUEST = _descriptor.Descriptor(
    name="SearchCatalogRequest",
    full_name="google.cloud.datacatalog.v1beta1.SearchCatalogRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="scope",
            full_name="google.cloud.datacatalog.v1beta1.SearchCatalogRequest.scope",
            index=0,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="query",
            full_name="google.cloud.datacatalog.v1beta1.SearchCatalogRequest.query",
            index=1,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.datacatalog.v1beta1.SearchCatalogRequest.page_size",
            index=2,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.datacatalog.v1beta1.SearchCatalogRequest.page_token",
            index=3,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="order_by",
            full_name="google.cloud.datacatalog.v1beta1.SearchCatalogRequest.order_by",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_SEARCHCATALOGREQUEST_SCOPE],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=720,
    serialized_end=1006,
)


_SEARCHCATALOGRESPONSE = _descriptor.Descriptor(
    name="SearchCatalogResponse",
    full_name="google.cloud.datacatalog.v1beta1.SearchCatalogResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="results",
            full_name="google.cloud.datacatalog.v1beta1.SearchCatalogResponse.results",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.datacatalog.v1beta1.SearchCatalogResponse.next_page_token",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1008,
    serialized_end=1128,
)


_CREATEENTRYGROUPREQUEST = _descriptor.Descriptor(
    name="CreateEntryGroupRequest",
    full_name="google.cloud.datacatalog.v1beta1.CreateEntryGroupRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.datacatalog.v1beta1.CreateEntryGroupRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A'\022%datacatalog.googleapis.com/EntryGroup",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="entry_group_id",
            full_name="google.cloud.datacatalog.v1beta1.CreateEntryGroupRequest.entry_group_id",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="entry_group",
            full_name="google.cloud.datacatalog.v1beta1.CreateEntryGroupRequest.entry_group",
            index=2,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1131,
    serialized_end=1315,
)


_UPDATEENTRYGROUPREQUEST = _descriptor.Descriptor(
    name="UpdateEntryGroupRequest",
    full_name="google.cloud.datacatalog.v1beta1.UpdateEntryGroupRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="entry_group",
            full_name="google.cloud.datacatalog.v1beta1.UpdateEntryGroupRequest.entry_group",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.datacatalog.v1beta1.UpdateEntryGroupRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1318,
    serialized_end=1464,
)


_GETENTRYGROUPREQUEST = _descriptor.Descriptor(
    name="GetEntryGroupRequest",
    full_name="google.cloud.datacatalog.v1beta1.GetEntryGroupRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.GetEntryGroupRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A'\n%datacatalog.googleapis.com/EntryGroup",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="read_mask",
            full_name="google.cloud.datacatalog.v1beta1.GetEntryGroupRequest.read_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1467,
    serialized_end=1597,
)


_DELETEENTRYGROUPREQUEST = _descriptor.Descriptor(
    name="DeleteEntryGroupRequest",
    full_name="google.cloud.datacatalog.v1beta1.DeleteEntryGroupRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.DeleteEntryGroupRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A'\n%datacatalog.googleapis.com/EntryGroup",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="force",
            full_name="google.cloud.datacatalog.v1beta1.DeleteEntryGroupRequest.force",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1599,
    serialized_end=1705,
)


_LISTENTRYGROUPSREQUEST = _descriptor.Descriptor(
    name="ListEntryGroupsRequest",
    full_name="google.cloud.datacatalog.v1beta1.ListEntryGroupsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.datacatalog.v1beta1.ListEntryGroupsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A'\n%datacatalog.googleapis.com/EntryGroup",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.datacatalog.v1beta1.ListEntryGroupsRequest.page_size",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.datacatalog.v1beta1.ListEntryGroupsRequest.page_token",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1708,
    serialized_end=1844,
)


_LISTENTRYGROUPSRESPONSE = _descriptor.Descriptor(
    name="ListEntryGroupsResponse",
    full_name="google.cloud.datacatalog.v1beta1.ListEntryGroupsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="entry_groups",
            full_name="google.cloud.datacatalog.v1beta1.ListEntryGroupsResponse.entry_groups",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.datacatalog.v1beta1.ListEntryGroupsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1846,
    serialized_end=1964,
)


_CREATEENTRYREQUEST = _descriptor.Descriptor(
    name="CreateEntryRequest",
    full_name="google.cloud.datacatalog.v1beta1.CreateEntryRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.datacatalog.v1beta1.CreateEntryRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A'\n%datacatalog.googleapis.com/EntryGroup",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="entry_id",
            full_name="google.cloud.datacatalog.v1beta1.CreateEntryRequest.entry_id",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="entry",
            full_name="google.cloud.datacatalog.v1beta1.CreateEntryRequest.entry",
            index=2,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1967,
    serialized_end=2134,
)


_UPDATEENTRYREQUEST = _descriptor.Descriptor(
    name="UpdateEntryRequest",
    full_name="google.cloud.datacatalog.v1beta1.UpdateEntryRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="entry",
            full_name="google.cloud.datacatalog.v1beta1.UpdateEntryRequest.entry",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.datacatalog.v1beta1.UpdateEntryRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2137,
    serialized_end=2267,
)


_DELETEENTRYREQUEST = _descriptor.Descriptor(
    name="DeleteEntryRequest",
    full_name="google.cloud.datacatalog.v1beta1.DeleteEntryRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.DeleteEntryRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b'\340A\002\372A"\n datacatalog.googleapis.com/Entry',
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2269,
    serialized_end=2345,
)


_GETENTRYREQUEST = _descriptor.Descriptor(
    name="GetEntryRequest",
    full_name="google.cloud.datacatalog.v1beta1.GetEntryRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.GetEntryRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b'\340A\002\372A"\n datacatalog.googleapis.com/Entry',
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2347,
    serialized_end=2420,
)


_LOOKUPENTRYREQUEST = _descriptor.Descriptor(
    name="LookupEntryRequest",
    full_name="google.cloud.datacatalog.v1beta1.LookupEntryRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="linked_resource",
            full_name="google.cloud.datacatalog.v1beta1.LookupEntryRequest.linked_resource",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="sql_resource",
            full_name="google.cloud.datacatalog.v1beta1.LookupEntryRequest.sql_resource",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="target_name",
            full_name="google.cloud.datacatalog.v1beta1.LookupEntryRequest.target_name",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=2422,
    serialized_end=2508,
)


_ENTRY = _descriptor.Descriptor(
    name="Entry",
    full_name="google.cloud.datacatalog.v1beta1.Entry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.Entry.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\372A'\n%datacatalog.googleapis.com/EntryGroup",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="linked_resource",
            full_name="google.cloud.datacatalog.v1beta1.Entry.linked_resource",
            index=1,
            number=9,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="type",
            full_name="google.cloud.datacatalog.v1beta1.Entry.type",
            index=2,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="user_specified_type",
            full_name="google.cloud.datacatalog.v1beta1.Entry.user_specified_type",
            index=3,
            number=16,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="integrated_system",
            full_name="google.cloud.datacatalog.v1beta1.Entry.integrated_system",
            index=4,
            number=17,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="user_specified_system",
            full_name="google.cloud.datacatalog.v1beta1.Entry.user_specified_system",
            index=5,
            number=18,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="gcs_fileset_spec",
            full_name="google.cloud.datacatalog.v1beta1.Entry.gcs_fileset_spec",
            index=6,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="bigquery_table_spec",
            full_name="google.cloud.datacatalog.v1beta1.Entry.bigquery_table_spec",
            index=7,
            number=12,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="bigquery_date_sharded_spec",
            full_name="google.cloud.datacatalog.v1beta1.Entry.bigquery_date_sharded_spec",
            index=8,
            number=15,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.datacatalog.v1beta1.Entry.display_name",
            index=9,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.datacatalog.v1beta1.Entry.description",
            index=10,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="schema",
            full_name="google.cloud.datacatalog.v1beta1.Entry.schema",
            index=11,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="source_system_timestamps",
            full_name="google.cloud.datacatalog.v1beta1.Entry.source_system_timestamps",
            index=12,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"\352Au\n datacatalog.googleapis.com/Entry\022Qprojects/{project}/locations/{location}/entryGroups/{entry_group}/entries/{entry}",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="entry_type",
            full_name="google.cloud.datacatalog.v1beta1.Entry.entry_type",
            index=0,
            containing_type=None,
            fields=[],
        ),
        _descriptor.OneofDescriptor(
            name="system",
            full_name="google.cloud.datacatalog.v1beta1.Entry.system",
            index=1,
            containing_type=None,
            fields=[],
        ),
        _descriptor.OneofDescriptor(
            name="type_spec",
            full_name="google.cloud.datacatalog.v1beta1.Entry.type_spec",
            index=2,
            containing_type=None,
            fields=[],
        ),
    ],
    serialized_start=2511,
    serialized_end=3422,
)


_ENTRYGROUP = _descriptor.Descriptor(
    name="EntryGroup",
    full_name="google.cloud.datacatalog.v1beta1.EntryGroup",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.EntryGroup.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.datacatalog.v1beta1.EntryGroup.display_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.datacatalog.v1beta1.EntryGroup.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="data_catalog_timestamps",
            full_name="google.cloud.datacatalog.v1beta1.EntryGroup.data_catalog_timestamps",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"\352Aj\n%datacatalog.googleapis.com/EntryGroup\022Aprojects/{project}/locations/{location}/entryGroups/{entry_group}",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3425,
    serialized_end=3695,
)


_CREATETAGTEMPLATEREQUEST = _descriptor.Descriptor(
    name="CreateTagTemplateRequest",
    full_name="google.cloud.datacatalog.v1beta1.CreateTagTemplateRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.datacatalog.v1beta1.CreateTagTemplateRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A(\022&datacatalog.googleapis.com/TagTemplate",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="tag_template_id",
            full_name="google.cloud.datacatalog.v1beta1.CreateTagTemplateRequest.tag_template_id",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="tag_template",
            full_name="google.cloud.datacatalog.v1beta1.CreateTagTemplateRequest.tag_template",
            index=2,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3698,
    serialized_end=3892,
)


_GETTAGTEMPLATEREQUEST = _descriptor.Descriptor(
    name="GetTagTemplateRequest",
    full_name="google.cloud.datacatalog.v1beta1.GetTagTemplateRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.GetTagTemplateRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A(\n&datacatalog.googleapis.com/TagTemplate",
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3894,
    serialized_end=3979,
)


_UPDATETAGTEMPLATEREQUEST = _descriptor.Descriptor(
    name="UpdateTagTemplateRequest",
    full_name="google.cloud.datacatalog.v1beta1.UpdateTagTemplateRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="tag_template",
            full_name="google.cloud.datacatalog.v1beta1.UpdateTagTemplateRequest.tag_template",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.datacatalog.v1beta1.UpdateTagTemplateRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3982,
    serialized_end=4131,
)


_DELETETAGTEMPLATEREQUEST = _descriptor.Descriptor(
    name="DeleteTagTemplateRequest",
    full_name="google.cloud.datacatalog.v1beta1.DeleteTagTemplateRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.DeleteTagTemplateRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A(\n&datacatalog.googleapis.com/TagTemplate",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="force",
            full_name="google.cloud.datacatalog.v1beta1.DeleteTagTemplateRequest.force",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4133,
    serialized_end=4241,
)


_CREATETAGREQUEST = _descriptor.Descriptor(
    name="CreateTagRequest",
    full_name="google.cloud.datacatalog.v1beta1.CreateTagRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.datacatalog.v1beta1.CreateTagRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A \n\036datacatalog.googleapis.com/Tag",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="tag",
            full_name="google.cloud.datacatalog.v1beta1.CreateTagRequest.tag",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4244,
    serialized_end=4375,
)


_UPDATETAGREQUEST = _descriptor.Descriptor(
    name="UpdateTagRequest",
    full_name="google.cloud.datacatalog.v1beta1.UpdateTagRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="tag",
            full_name="google.cloud.datacatalog.v1beta1.UpdateTagRequest.tag",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.datacatalog.v1beta1.UpdateTagRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4377,
    serialized_end=4501,
)


_DELETETAGREQUEST = _descriptor.Descriptor(
    name="DeleteTagRequest",
    full_name="google.cloud.datacatalog.v1beta1.DeleteTagRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.DeleteTagRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A \022\036datacatalog.googleapis.com/Tag",
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4503,
    serialized_end=4575,
)


_CREATETAGTEMPLATEFIELDREQUEST = _descriptor.Descriptor(
    name="CreateTagTemplateFieldRequest",
    full_name="google.cloud.datacatalog.v1beta1.CreateTagTemplateFieldRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.datacatalog.v1beta1.CreateTagTemplateFieldRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A(\n&datacatalog.googleapis.com/TagTemplate",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="tag_template_field_id",
            full_name="google.cloud.datacatalog.v1beta1.CreateTagTemplateFieldRequest.tag_template_field_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="tag_template_field",
            full_name="google.cloud.datacatalog.v1beta1.CreateTagTemplateFieldRequest.tag_template_field",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4578,
    serialized_end=4794,
)


_UPDATETAGTEMPLATEFIELDREQUEST = _descriptor.Descriptor(
    name="UpdateTagTemplateFieldRequest",
    full_name="google.cloud.datacatalog.v1beta1.UpdateTagTemplateFieldRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.UpdateTagTemplateFieldRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A-\n+datacatalog.googleapis.com/TagTemplateField",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="tag_template_field",
            full_name="google.cloud.datacatalog.v1beta1.UpdateTagTemplateFieldRequest.tag_template_field",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.datacatalog.v1beta1.UpdateTagTemplateFieldRequest.update_mask",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4797,
    serialized_end=5034,
)


_RENAMETAGTEMPLATEFIELDREQUEST = _descriptor.Descriptor(
    name="RenameTagTemplateFieldRequest",
    full_name="google.cloud.datacatalog.v1beta1.RenameTagTemplateFieldRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.RenameTagTemplateFieldRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A-\n+datacatalog.googleapis.com/TagTemplateField",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="new_tag_template_field_id",
            full_name="google.cloud.datacatalog.v1beta1.RenameTagTemplateFieldRequest.new_tag_template_field_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5037,
    serialized_end=5175,
)


_DELETETAGTEMPLATEFIELDREQUEST = _descriptor.Descriptor(
    name="DeleteTagTemplateFieldRequest",
    full_name="google.cloud.datacatalog.v1beta1.DeleteTagTemplateFieldRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.DeleteTagTemplateFieldRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A-\n+datacatalog.googleapis.com/TagTemplateField",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="force",
            full_name="google.cloud.datacatalog.v1beta1.DeleteTagTemplateFieldRequest.force",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5177,
    serialized_end=5295,
)


_LISTTAGSREQUEST = _descriptor.Descriptor(
    name="ListTagsRequest",
    full_name="google.cloud.datacatalog.v1beta1.ListTagsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.datacatalog.v1beta1.ListTagsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A \022\036datacatalog.googleapis.com/Tag",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.datacatalog.v1beta1.ListTagsRequest.page_size",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.datacatalog.v1beta1.ListTagsRequest.page_token",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5297,
    serialized_end=5409,
)


_LISTTAGSRESPONSE = _descriptor.Descriptor(
    name="ListTagsResponse",
    full_name="google.cloud.datacatalog.v1beta1.ListTagsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="tags",
            full_name="google.cloud.datacatalog.v1beta1.ListTagsResponse.tags",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.datacatalog.v1beta1.ListTagsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5411,
    serialized_end=5507,
)


_LISTENTRIESREQUEST = _descriptor.Descriptor(
    name="ListEntriesRequest",
    full_name="google.cloud.datacatalog.v1beta1.ListEntriesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.datacatalog.v1beta1.ListEntriesRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A'\n%datacatalog.googleapis.com/EntryGroup",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.datacatalog.v1beta1.ListEntriesRequest.page_size",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.datacatalog.v1beta1.ListEntriesRequest.page_token",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="read_mask",
            full_name="google.cloud.datacatalog.v1beta1.ListEntriesRequest.read_mask",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5510,
    serialized_end=5679,
)


_LISTENTRIESRESPONSE = _descriptor.Descriptor(
    name="ListEntriesResponse",
    full_name="google.cloud.datacatalog.v1beta1.ListEntriesResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="entries",
            full_name="google.cloud.datacatalog.v1beta1.ListEntriesResponse.entries",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.datacatalog.v1beta1.ListEntriesResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5681,
    serialized_end=5785,
)

_SEARCHCATALOGREQUEST_SCOPE.containing_type = _SEARCHCATALOGREQUEST
_SEARCHCATALOGREQUEST.fields_by_name["scope"].message_type = _SEARCHCATALOGREQUEST_SCOPE
_SEARCHCATALOGRESPONSE.fields_by_name[
    "results"
].message_type = (
    google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_search__pb2._SEARCHCATALOGRESULT
)
_CREATEENTRYGROUPREQUEST.fields_by_name["entry_group"].message_type = _ENTRYGROUP
_UPDATEENTRYGROUPREQUEST.fields_by_name["entry_group"].message_type = _ENTRYGROUP
_UPDATEENTRYGROUPREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_GETENTRYGROUPREQUEST.fields_by_name[
    "read_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTENTRYGROUPSRESPONSE.fields_by_name["entry_groups"].message_type = _ENTRYGROUP
_CREATEENTRYREQUEST.fields_by_name["entry"].message_type = _ENTRY
_UPDATEENTRYREQUEST.fields_by_name["entry"].message_type = _ENTRY
_UPDATEENTRYREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LOOKUPENTRYREQUEST.oneofs_by_name["target_name"].fields.append(
    _LOOKUPENTRYREQUEST.fields_by_name["linked_resource"]
)
_LOOKUPENTRYREQUEST.fields_by_name[
    "linked_resource"
].containing_oneof = _LOOKUPENTRYREQUEST.oneofs_by_name["target_name"]
_LOOKUPENTRYREQUEST.oneofs_by_name["target_name"].fields.append(
    _LOOKUPENTRYREQUEST.fields_by_name["sql_resource"]
)
_LOOKUPENTRYREQUEST.fields_by_name[
    "sql_resource"
].containing_oneof = _LOOKUPENTRYREQUEST.oneofs_by_name["target_name"]
_ENTRY.fields_by_name["type"].enum_type = _ENTRYTYPE
_ENTRY.fields_by_name[
    "integrated_system"
].enum_type = (
    google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_common__pb2._INTEGRATEDSYSTEM
)
_ENTRY.fields_by_name[
    "gcs_fileset_spec"
].message_type = (
    google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_gcs__fileset__spec__pb2._GCSFILESETSPEC
)
_ENTRY.fields_by_name[
    "bigquery_table_spec"
].message_type = (
    google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_table__spec__pb2._BIGQUERYTABLESPEC
)
_ENTRY.fields_by_name[
    "bigquery_date_sharded_spec"
].message_type = (
    google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_table__spec__pb2._BIGQUERYDATESHARDEDSPEC
)
_ENTRY.fields_by_name[
    "schema"
].message_type = (
    google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_schema__pb2._SCHEMA
)
_ENTRY.fields_by_name[
    "source_system_timestamps"
].message_type = (
    google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_timestamps__pb2._SYSTEMTIMESTAMPS
)
_ENTRY.oneofs_by_name["entry_type"].fields.append(_ENTRY.fields_by_name["type"])
_ENTRY.fields_by_name["type"].containing_oneof = _ENTRY.oneofs_by_name["entry_type"]
_ENTRY.oneofs_by_name["entry_type"].fields.append(
    _ENTRY.fields_by_name["user_specified_type"]
)
_ENTRY.fields_by_name["user_specified_type"].containing_oneof = _ENTRY.oneofs_by_name[
    "entry_type"
]
_ENTRY.oneofs_by_name["system"].fields.append(
    _ENTRY.fields_by_name["integrated_system"]
)
_ENTRY.fields_by_name["integrated_system"].containing_oneof = _ENTRY.oneofs_by_name[
    "system"
]
_ENTRY.oneofs_by_name["system"].fields.append(
    _ENTRY.fields_by_name["user_specified_system"]
)
_ENTRY.fields_by_name["user_specified_system"].containing_oneof = _ENTRY.oneofs_by_name[
    "system"
]
_ENTRY.oneofs_by_name["type_spec"].fields.append(
    _ENTRY.fields_by_name["gcs_fileset_spec"]
)
_ENTRY.fields_by_name["gcs_fileset_spec"].containing_oneof = _ENTRY.oneofs_by_name[
    "type_spec"
]
_ENTRY.oneofs_by_name["type_spec"].fields.append(
    _ENTRY.fields_by_name["bigquery_table_spec"]
)
_ENTRY.fields_by_name["bigquery_table_spec"].containing_oneof = _ENTRY.oneofs_by_name[
    "type_spec"
]
_ENTRY.oneofs_by_name["type_spec"].fields.append(
    _ENTRY.fields_by_name["bigquery_date_sharded_spec"]
)
_ENTRY.fields_by_name[
    "bigquery_date_sharded_spec"
].containing_oneof = _ENTRY.oneofs_by_name["type_spec"]
_ENTRYGROUP.fields_by_name[
    "data_catalog_timestamps"
].message_type = (
    google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_timestamps__pb2._SYSTEMTIMESTAMPS
)
_CREATETAGTEMPLATEREQUEST.fields_by_name[
    "tag_template"
].message_type = (
    google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAGTEMPLATE
)
_UPDATETAGTEMPLATEREQUEST.fields_by_name[
    "tag_template"
].message_type = (
    google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAGTEMPLATE
)
_UPDATETAGTEMPLATEREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_CREATETAGREQUEST.fields_by_name[
    "tag"
].message_type = google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAG
_UPDATETAGREQUEST.fields_by_name[
    "tag"
].message_type = google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAG
_UPDATETAGREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_CREATETAGTEMPLATEFIELDREQUEST.fields_by_name[
    "tag_template_field"
].message_type = (
    google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAGTEMPLATEFIELD
)
_UPDATETAGTEMPLATEFIELDREQUEST.fields_by_name[
    "tag_template_field"
].message_type = (
    google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAGTEMPLATEFIELD
)
_UPDATETAGTEMPLATEFIELDREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTTAGSRESPONSE.fields_by_name[
    "tags"
].message_type = google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAG
_LISTENTRIESREQUEST.fields_by_name[
    "read_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTENTRIESRESPONSE.fields_by_name["entries"].message_type = _ENTRY
DESCRIPTOR.message_types_by_name["SearchCatalogRequest"] = _SEARCHCATALOGREQUEST
DESCRIPTOR.message_types_by_name["SearchCatalogResponse"] = _SEARCHCATALOGRESPONSE
DESCRIPTOR.message_types_by_name["CreateEntryGroupRequest"] = _CREATEENTRYGROUPREQUEST
DESCRIPTOR.message_types_by_name["UpdateEntryGroupRequest"] = _UPDATEENTRYGROUPREQUEST
DESCRIPTOR.message_types_by_name["GetEntryGroupRequest"] = _GETENTRYGROUPREQUEST
DESCRIPTOR.message_types_by_name["DeleteEntryGroupRequest"] = _DELETEENTRYGROUPREQUEST
DESCRIPTOR.message_types_by_name["ListEntryGroupsRequest"] = _LISTENTRYGROUPSREQUEST
DESCRIPTOR.message_types_by_name["ListEntryGroupsResponse"] = _LISTENTRYGROUPSRESPONSE
DESCRIPTOR.message_types_by_name["CreateEntryRequest"] = _CREATEENTRYREQUEST
DESCRIPTOR.message_types_by_name["UpdateEntryRequest"] = _UPDATEENTRYREQUEST
DESCRIPTOR.message_types_by_name["DeleteEntryRequest"] = _DELETEENTRYREQUEST
DESCRIPTOR.message_types_by_name["GetEntryRequest"] = _GETENTRYREQUEST
DESCRIPTOR.message_types_by_name["LookupEntryRequest"] = _LOOKUPENTRYREQUEST
DESCRIPTOR.message_types_by_name["Entry"] = _ENTRY
DESCRIPTOR.message_types_by_name["EntryGroup"] = _ENTRYGROUP
DESCRIPTOR.message_types_by_name["CreateTagTemplateRequest"] = _CREATETAGTEMPLATEREQUEST
DESCRIPTOR.message_types_by_name["GetTagTemplateRequest"] = _GETTAGTEMPLATEREQUEST
DESCRIPTOR.message_types_by_name["UpdateTagTemplateRequest"] = _UPDATETAGTEMPLATEREQUEST
DESCRIPTOR.message_types_by_name["DeleteTagTemplateRequest"] = _DELETETAGTEMPLATEREQUEST
DESCRIPTOR.message_types_by_name["CreateTagRequest"] = _CREATETAGREQUEST
DESCRIPTOR.message_types_by_name["UpdateTagRequest"] = _UPDATETAGREQUEST
DESCRIPTOR.message_types_by_name["DeleteTagRequest"] = _DELETETAGREQUEST
DESCRIPTOR.message_types_by_name[
    "CreateTagTemplateFieldRequest"
] = _CREATETAGTEMPLATEFIELDREQUEST
DESCRIPTOR.message_types_by_name[
    "UpdateTagTemplateFieldRequest"
] = _UPDATETAGTEMPLATEFIELDREQUEST
DESCRIPTOR.message_types_by_name[
    "RenameTagTemplateFieldRequest"
] = _RENAMETAGTEMPLATEFIELDREQUEST
DESCRIPTOR.message_types_by_name[
    "DeleteTagTemplateFieldRequest"
] = _DELETETAGTEMPLATEFIELDREQUEST
DESCRIPTOR.message_types_by_name["ListTagsRequest"] = _LISTTAGSREQUEST
DESCRIPTOR.message_types_by_name["ListTagsResponse"] = _LISTTAGSRESPONSE
DESCRIPTOR.message_types_by_name["ListEntriesRequest"] = _LISTENTRIESREQUEST
DESCRIPTOR.message_types_by_name["ListEntriesResponse"] = _LISTENTRIESRESPONSE
DESCRIPTOR.enum_types_by_name["EntryType"] = _ENTRYTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SearchCatalogRequest = _reflection.GeneratedProtocolMessageType(
    "SearchCatalogRequest",
    (_message.Message,),
    {
        "Scope": _reflection.GeneratedProtocolMessageType(
            "Scope",
            (_message.Message,),
            {
                "DESCRIPTOR": _SEARCHCATALOGREQUEST_SCOPE,
                "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
                "__doc__": """The criteria that select the subspace used for query
    matching.
    
    
    Attributes:
        include_org_ids:
            The list of organization IDs to search within. To find your
            organization ID, follow instructions in
            https://cloud.google.com/resource-manager/docs/creating-
            managing-organization.
        include_project_ids:
            The list of project IDs to search within. To learn more about
            the distinction between project names/IDs/numbers, go to
            https://cloud.google.com/docs/overview/#projects.
        include_gcp_public_datasets:
            If ``true``, include Google Cloud Platform (GCP) public
            datasets in the search results. Info on GCP public datasets is
            available at https://cloud.google.com/public-datasets/. By
            default, GCP public datasets are excluded.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.SearchCatalogRequest.Scope)
            },
        ),
        "DESCRIPTOR": _SEARCHCATALOGREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Request message for
  [SearchCatalog][google.cloud.datacatalog.v1beta1.DataCatalog.SearchCatalog].
  
  
  Attributes:
      scope:
          Required. The scope of this search request. A ``scope`` that
          has empty ``include_org_ids``, ``include_project_ids`` AND
          false ``include_gcp_public_datasets`` is considered invalid.
          Data Catalog will return an error in such a case.
      query:
          Required. The query string in search query syntax. The query
          must be non-empty.  Query strings can be simple as “x” or more
          qualified as:  -  name:x -  column:x -  description:y  Note:
          Query tokens need to have a minimum of 3 characters for
          substring matching to work correctly. See `Data Catalog Search
          Syntax <https://cloud.google.com/data-catalog/docs/how-
          to/search-reference>`__ for more information.
      page_size:
          Number of results in the search page. If <=0 then defaults to
          10. Max limit for page_size is 1000. Throws an invalid
          argument for page_size > 1000.
      page_token:
          Optional. Pagination token returned in an earlier [SearchCatal
          ogResponse.next_page_token][google.cloud.datacatalog.v1beta1.S
          earchCatalogResponse.next_page_token], which indicates that
          this is a continuation of a prior [SearchCatalogRequest][googl
          e.cloud.datacatalog.v1beta1.DataCatalog.SearchCatalog] call,
          and that the system should return the next page of data. If
          empty, the first page is returned.
      order_by:
          Specifies the ordering of results, currently supported case-
          sensitive choices are:  -  ``relevance``, only supports
          descending -  ``last_modified_timestamp [asc|desc]``, defaults
          to descending if not    specified  If not specified, defaults
          to ``relevance`` descending.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.SearchCatalogRequest)
    },
)
_sym_db.RegisterMessage(SearchCatalogRequest)
_sym_db.RegisterMessage(SearchCatalogRequest.Scope)

SearchCatalogResponse = _reflection.GeneratedProtocolMessageType(
    "SearchCatalogResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _SEARCHCATALOGRESPONSE,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Response message for
  [SearchCatalog][google.cloud.datacatalog.v1beta1.DataCatalog.SearchCatalog].
  
  
  Attributes:
      results:
          Search results.
      next_page_token:
          The token that can be used to retrieve the next page of
          results.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.SearchCatalogResponse)
    },
)
_sym_db.RegisterMessage(SearchCatalogResponse)

CreateEntryGroupRequest = _reflection.GeneratedProtocolMessageType(
    "CreateEntryGroupRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATEENTRYGROUPREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Request message for
  [CreateEntryGroup][google.cloud.datacatalog.v1beta1.DataCatalog.CreateEntryGroup].
  
  
  Attributes:
      parent:
          Required. The name of the project this entry group is in.
          Example:  -  projects/{project_id}/locations/{location}  Note
          that this EntryGroup and its child resources may not actually
          be stored in the location in this name.
      entry_group_id:
          Required. The id of the entry group to create. The id must
          begin with a letter or underscore, contain only English
          letters, numbers and underscores, and be at most 64
          characters.
      entry_group:
          The entry group to create. Defaults to an empty entry group.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.CreateEntryGroupRequest)
    },
)
_sym_db.RegisterMessage(CreateEntryGroupRequest)

UpdateEntryGroupRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateEntryGroupRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATEENTRYGROUPREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Request message for
  [UpdateEntryGroup][google.cloud.datacatalog.v1beta1.DataCatalog.UpdateEntryGroup].
  
  
  Attributes:
      entry_group:
          Required. The updated entry group. “name” field must be set.
      update_mask:
          The fields to update on the entry group. If absent or empty,
          all modifiable fields are updated.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.UpdateEntryGroupRequest)
    },
)
_sym_db.RegisterMessage(UpdateEntryGroupRequest)

GetEntryGroupRequest = _reflection.GeneratedProtocolMessageType(
    "GetEntryGroupRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETENTRYGROUPREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Request message for
  [GetEntryGroup][google.cloud.datacatalog.v1beta1.DataCatalog.GetEntryGroup].
  
  
  Attributes:
      name:
          Required. The name of the entry group. For example, ``projects
          /{project_id}/locations/{location}/entryGroups/{entry_group_id
          }``.
      read_mask:
          The fields to return. If not set or empty, all fields are
          returned.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.GetEntryGroupRequest)
    },
)
_sym_db.RegisterMessage(GetEntryGroupRequest)

DeleteEntryGroupRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteEntryGroupRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETEENTRYGROUPREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Request message for
  [DeleteEntryGroup][google.cloud.datacatalog.v1beta1.DataCatalog.DeleteEntryGroup].
  
  
  Attributes:
      name:
          Required. The name of the entry group. For example, ``projects
          /{project_id}/locations/{location}/entryGroups/{entry_group_id
          }``.
      force:
          Optional. If true, deletes all entries in the entry group.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.DeleteEntryGroupRequest)
    },
)
_sym_db.RegisterMessage(DeleteEntryGroupRequest)

ListEntryGroupsRequest = _reflection.GeneratedProtocolMessageType(
    "ListEntryGroupsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTENTRYGROUPSREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Request message for
  [ListEntryGroups][google.cloud.datacatalog.v1beta1.DataCatalog.ListEntryGroups].
  
  
  Attributes:
      parent:
          Required. The name of the location that contains the entry
          groups, which can be provided in URL format. Example:  -
          projects/{project_id}/locations/{location}
      page_size:
          Optional. The maximum number of items to return. Default is
          10. Max limit is 1000. Throws an invalid argument for
          ``page_size > 1000``.
      page_token:
          Optional. Token that specifies which page is requested. If
          empty, the first page is returned.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.ListEntryGroupsRequest)
    },
)
_sym_db.RegisterMessage(ListEntryGroupsRequest)

ListEntryGroupsResponse = _reflection.GeneratedProtocolMessageType(
    "ListEntryGroupsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTENTRYGROUPSRESPONSE,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Response message for
  [ListEntryGroups][google.cloud.datacatalog.v1beta1.DataCatalog.ListEntryGroups].
  
  
  Attributes:
      entry_groups:
          EntryGroup details.
      next_page_token:
          Token to retrieve the next page of results. It is set to empty
          if no items remain in results.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.ListEntryGroupsResponse)
    },
)
_sym_db.RegisterMessage(ListEntryGroupsResponse)

CreateEntryRequest = _reflection.GeneratedProtocolMessageType(
    "CreateEntryRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATEENTRYREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Request message for
  [CreateEntry][google.cloud.datacatalog.v1beta1.DataCatalog.CreateEntry].
  
  
  Attributes:
      parent:
          Required. The name of the entry group this entry is in.
          Example:  -  projects/{project_id}/locations/{location}/entryG
          roups/{entry_group_id}  Note that this Entry and its child
          resources may not actually be stored in the location in this
          name.
      entry_id:
          Required. The id of the entry to create.
      entry:
          Required. The entry to create.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.CreateEntryRequest)
    },
)
_sym_db.RegisterMessage(CreateEntryRequest)

UpdateEntryRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateEntryRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATEENTRYREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Request message for
  [UpdateEntry][google.cloud.datacatalog.v1beta1.DataCatalog.UpdateEntry].
  
  
  Attributes:
      entry:
          Required. The updated entry. The “name” field must be set.
      update_mask:
          The fields to update on the entry. If absent or empty, all
          modifiable fields are updated.  The following fields are
          modifiable: \* For entries with type ``DATA_STREAM``: \*
          ``schema`` \* For entries with type ``FILESET`` \* ``schema``
          \* ``display_name`` \* ``description`` \* ``gcs_fileset_spec``
          \* ``gcs_fileset_spec.file_patterns`` \* For entries with
          ``user_specified_type`` \* ``schema`` \* ``display_name`` \*
          ``description`` \* user_specified_type \*
          user_specified_system \* linked_resource \*
          source_system_timestamps
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.UpdateEntryRequest)
    },
)
_sym_db.RegisterMessage(UpdateEntryRequest)

DeleteEntryRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteEntryRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETEENTRYREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Request message for
  [DeleteEntry][google.cloud.datacatalog.v1beta1.DataCatalog.DeleteEntry].
  
  
  Attributes:
      name:
          Required. The name of the entry. Example:  -  projects/{projec
          t_id}/locations/{location}/entryGroups/{entry_group_id}/entrie
          s/{entry_id}
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.DeleteEntryRequest)
    },
)
_sym_db.RegisterMessage(DeleteEntryRequest)

GetEntryRequest = _reflection.GeneratedProtocolMessageType(
    "GetEntryRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETENTRYREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Request message for
  [GetEntry][google.cloud.datacatalog.v1beta1.DataCatalog.GetEntry].
  
  
  Attributes:
      name:
          Required. The name of the entry. Example:  -  projects/{projec
          t_id}/locations/{location}/entryGroups/{entry_group_id}/entrie
          s/{entry_id}
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.GetEntryRequest)
    },
)
_sym_db.RegisterMessage(GetEntryRequest)

LookupEntryRequest = _reflection.GeneratedProtocolMessageType(
    "LookupEntryRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LOOKUPENTRYREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Request message for
  [LookupEntry][google.cloud.datacatalog.v1beta1.DataCatalog.LookupEntry].
  
  
  Attributes:
      target_name:
          Required. Represents either the Google Cloud Platform resource
          or SQL name for a Google Cloud Platform resource.
      linked_resource:
          The full name of the Google Cloud Platform resource the Data
          Catalog entry represents. See: https://cloud.google.com/apis/d
          esign/resource_names#full_resource_name. Full names are case-
          sensitive.  Examples:  -  //bigquery.googleapis.com/projects/p
          rojectId/datasets/datasetId/tables/tableId -
          //pubsub.googleapis.com/projects/projectId/topics/topicId
      sql_resource:
          The SQL name of the entry. SQL names are case-sensitive.
          Examples:  -  ``pubsub.project_id.topic_id`` -
          :literal:`pubsub.project_id.`topic.id.with.dots\`` -
          ``bigquery.table.project_id.dataset_id.table_id`` -
          ``bigquery.dataset.project_id.dataset_id`` -  ``datacatalog.en
          try.project_id.location_id.entry_group_id.entry_id``
          ``*_id``\ s shoud satisfy the standard SQL rules for
          identifiers.
          https://cloud.google.com/bigquery/docs/reference/standard-
          sql/lexical.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.LookupEntryRequest)
    },
)
_sym_db.RegisterMessage(LookupEntryRequest)

Entry = _reflection.GeneratedProtocolMessageType(
    "Entry",
    (_message.Message,),
    {
        "DESCRIPTOR": _ENTRY,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Entry Metadata. A Data Catalog Entry resource represents
  another resource in Google Cloud Platform (such as a BigQuery dataset or
  a Pub/Sub topic), or outside of Google Cloud Platform. Clients can use
  the ``linked_resource`` field in the Entry resource to refer to the
  original resource ID of the source system.
  
  An Entry resource contains resource details, such as its schema. An
  Entry can also be used to attach flexible metadata, such as a
  [Tag][google.cloud.datacatalog.v1beta1.Tag].
  
  
  Attributes:
      name:
          The Data Catalog resource name of the entry in URL format.
          Example:  -  projects/{project_id}/locations/{location}/entryG
          roups/{entry_group_id}/entries/{entry_id}  Note that this
          Entry and its child resources may not actually be stored in
          the location in this name.
      linked_resource:
          The resource this metadata entry refers to.  For Google Cloud
          Platform resources, ``linked_resource`` is the `full name of
          the resource <https://cloud.google.com/apis/design/resource_na
          mes#full_resource_name>`__. For example, the
          ``linked_resource`` for a table resource from BigQuery is:  -
          //bigquery.googleapis.com/projects/projectId/datasets/datasetI
          d/tables/tableId  Output only when Entry is of type in the
          EntryType enum. For entries with user_specified_type, this
          field is optional and defaults to an empty string.
      entry_type:
          Required. Entry type.
      type:
          The type of the entry. Only used for Entries with types in the
          EntryType enum.
      user_specified_type:
          Entry type if it does not fit any of the input-allowed values
          listed in ``EntryType`` enum above. When creating an entry,
          users should check the enum values first, if nothing matches
          the entry to be created, then provide a custom value, for
          example “my_special_type”. ``user_specified_type`` strings
          must begin with a letter or underscore and can only contain
          letters, numbers, and underscores; are case insensitive; must
          be at least 1 character and at most 64 characters long.
          Currently, only FILESET enum value is allowed. All other
          entries created through Data Catalog must use
          ``user_specified_type``.
      system:
          The source system of the entry.
      integrated_system:
          Output only. This field indicates the entry’s source system
          that Data Catalog integrates with, such as BigQuery or
          Pub/Sub.
      user_specified_system:
          This field indicates the entry’s source system that Data
          Catalog does not integrate with. ``user_specified_system``
          strings must begin with a letter or underscore and can only
          contain letters, numbers, and underscores; are case
          insensitive; must be at least 1 character and at most 64
          characters long.
      type_spec:
          Type specification information.
      gcs_fileset_spec:
          Specification that applies to a Cloud Storage fileset. This is
          only valid on entries of type FILESET.
      bigquery_table_spec:
          Specification that applies to a BigQuery table. This is only
          valid on entries of type ``TABLE``.
      bigquery_date_sharded_spec:
          Specification for a group of BigQuery tables with name pattern
          ``[prefix]YYYYMMDD``. Context:
          https://cloud.google.com/bigquery/docs/partitioned-
          tables#partitioning_versus_sharding.
      display_name:
          Display information such as title and description. A short
          name to identify the entry, for example, “Analytics Data - Jan
          2011”. Default value is an empty string.
      description:
          Entry description, which can consist of several sentences or
          paragraphs that describe entry contents. Default value is an
          empty string.
      schema:
          Schema of the entry. An entry might not have any schema
          attached to it.
      source_system_timestamps:
          Output only. Timestamps about the underlying resource, not
          about this Data Catalog entry. Output only when Entry is of
          type in the EntryType enum. For entries with
          user_specified_type, this field is optional and defaults to an
          empty timestamp.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.Entry)
    },
)
_sym_db.RegisterMessage(Entry)

EntryGroup = _reflection.GeneratedProtocolMessageType(
    "EntryGroup",
    (_message.Message,),
    {
        "DESCRIPTOR": _ENTRYGROUP,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """EntryGroup Metadata. An EntryGroup resource represents a
  logical grouping of zero or more Data Catalog
  [Entry][google.cloud.datacatalog.v1beta1.Entry] resources.
  
  
  Attributes:
      name:
          The resource name of the entry group in URL format. Example:
          -  projects/{project_id}/locations/{location}/entryGroups/{ent
          ry_group_id}  Note that this EntryGroup and its child
          resources may not actually be stored in the location in this
          name.
      display_name:
          A short name to identify the entry group, for example,
          “analytics data - jan 2011”. Default value is an empty string.
      description:
          Entry group description, which can consist of several
          sentences or paragraphs that describe entry group contents.
          Default value is an empty string.
      data_catalog_timestamps:
          Output only. Timestamps about this EntryGroup. Default value
          is empty timestamps.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.EntryGroup)
    },
)
_sym_db.RegisterMessage(EntryGroup)

CreateTagTemplateRequest = _reflection.GeneratedProtocolMessageType(
    "CreateTagTemplateRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATETAGTEMPLATEREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Request message for
  [CreateTagTemplate][google.cloud.datacatalog.v1beta1.DataCatalog.CreateTagTemplate].
  
  
  Attributes:
      parent:
          Required. The name of the project and the template location
          [region](https://cloud.google.com/data-
          catalog/docs/concepts/regions.  Example:  -
          projects/{project_id}/locations/us-central1
      tag_template_id:
          Required. The id of the tag template to create.
      tag_template:
          Required. The tag template to create.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.CreateTagTemplateRequest)
    },
)
_sym_db.RegisterMessage(CreateTagTemplateRequest)

GetTagTemplateRequest = _reflection.GeneratedProtocolMessageType(
    "GetTagTemplateRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETTAGTEMPLATEREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Request message for
  [GetTagTemplate][google.cloud.datacatalog.v1beta1.DataCatalog.GetTagTemplate].
  
  
  Attributes:
      name:
          Required. The name of the tag template. Example:  -  projects/
          {project_id}/locations/{location}/tagTemplates/{tag_template_i
          d}
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.GetTagTemplateRequest)
    },
)
_sym_db.RegisterMessage(GetTagTemplateRequest)

UpdateTagTemplateRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateTagTemplateRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATETAGTEMPLATEREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Request message for
  [UpdateTagTemplate][google.cloud.datacatalog.v1beta1.DataCatalog.UpdateTagTemplate].
  
  
  Attributes:
      tag_template:
          Required. The template to update. The “name” field must be
          set.
      update_mask:
          The field mask specifies the parts of the template to
          overwrite.  Allowed fields:  -  ``display_name``  If absent or
          empty, all of the allowed fields above will be updated.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.UpdateTagTemplateRequest)
    },
)
_sym_db.RegisterMessage(UpdateTagTemplateRequest)

DeleteTagTemplateRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteTagTemplateRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETETAGTEMPLATEREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Request message for
  [DeleteTagTemplate][google.cloud.datacatalog.v1beta1.DataCatalog.DeleteTagTemplate].
  
  
  Attributes:
      name:
          Required. The name of the tag template to delete. Example:  -
          projects/{project_id}/locations/{location}/tagTemplates/{tag_t
          emplate_id}
      force:
          Required. Currently, this field must always be set to
          ``true``. This confirms the deletion of any possible tags
          using this template. ``force = false`` will be supported in
          the future.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.DeleteTagTemplateRequest)
    },
)
_sym_db.RegisterMessage(DeleteTagTemplateRequest)

CreateTagRequest = _reflection.GeneratedProtocolMessageType(
    "CreateTagRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATETAGREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Request message for
  [CreateTag][google.cloud.datacatalog.v1beta1.DataCatalog.CreateTag].
  
  
  Attributes:
      parent:
          Required. The name of the resource to attach this tag to. Tags
          can be attached to Entries. Example:  -  projects/{project_id}
          /locations/{location}/entryGroups/{entry_group_id}/entries/{en
          try_id}  Note that this Tag and its child resources may not
          actually be stored in the location in this name.
      tag:
          Required. The tag to create.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.CreateTagRequest)
    },
)
_sym_db.RegisterMessage(CreateTagRequest)

UpdateTagRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateTagRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATETAGREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Request message for
  [UpdateTag][google.cloud.datacatalog.v1beta1.DataCatalog.UpdateTag].
  
  
  Attributes:
      tag:
          Required. The updated tag. The “name” field must be set.
      update_mask:
          The fields to update on the Tag. If absent or empty, all
          modifiable fields are updated. Currently the only modifiable
          field is the field ``fields``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.UpdateTagRequest)
    },
)
_sym_db.RegisterMessage(UpdateTagRequest)

DeleteTagRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteTagRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETETAGREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Request message for
  [DeleteTag][google.cloud.datacatalog.v1beta1.DataCatalog.DeleteTag].
  
  
  Attributes:
      name:
          Required. The name of the tag to delete. Example:  -  projects
          /{project_id}/locations/{location}/entryGroups/{entry_group_id
          }/entries/{entry_id}/tags/{tag_id}
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.DeleteTagRequest)
    },
)
_sym_db.RegisterMessage(DeleteTagRequest)

CreateTagTemplateFieldRequest = _reflection.GeneratedProtocolMessageType(
    "CreateTagTemplateFieldRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATETAGTEMPLATEFIELDREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Request message for
  [CreateTagTemplateField][google.cloud.datacatalog.v1beta1.DataCatalog.CreateTagTemplateField].
  
  
  Attributes:
      parent:
          Required. The name of the project and the template location
          `region <https://cloud.google.com/data-
          catalog/docs/concepts/regions>`__.  Example:  -
          projects/{project_id}/locations/us-
          central1/tagTemplates/{tag_template_id}
      tag_template_field_id:
          Required. The ID of the tag template field to create. Field
          ids can contain letters (both uppercase and lowercase),
          numbers (0-9), underscores (_) and dashes (-). Field IDs must
          be at least 1 character long and at most 128 characters long.
          Field IDs must also be unique within their template.
      tag_template_field:
          Required. The tag template field to create.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.CreateTagTemplateFieldRequest)
    },
)
_sym_db.RegisterMessage(CreateTagTemplateFieldRequest)

UpdateTagTemplateFieldRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateTagTemplateFieldRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATETAGTEMPLATEFIELDREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Request message for
  [UpdateTagTemplateField][google.cloud.datacatalog.v1beta1.DataCatalog.UpdateTagTemplateField].
  
  
  Attributes:
      name:
          Required. The name of the tag template field. Example:  -  pro
          jects/{project_id}/locations/{location}/tagTemplates/{tag_temp
          late_id}/fields/{tag_template_field_id}
      tag_template_field:
          Required. The template to update.
      update_mask:
          Optional. The field mask specifies the parts of the template
          to be updated. Allowed fields:  -  ``display_name`` -
          ``type.enum_type`` -  ``is_required``  If ``update_mask`` is
          not set or empty, all of the allowed fields above will be
          updated.  When updating an enum type, the provided values will
          be merged with the existing values. Therefore, enum values can
          only be added, existing enum values cannot be deleted nor
          renamed. Updating a template field from optional to required
          is NOT allowed.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.UpdateTagTemplateFieldRequest)
    },
)
_sym_db.RegisterMessage(UpdateTagTemplateFieldRequest)

RenameTagTemplateFieldRequest = _reflection.GeneratedProtocolMessageType(
    "RenameTagTemplateFieldRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _RENAMETAGTEMPLATEFIELDREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Request message for
  [RenameTagTemplateField][google.cloud.datacatalog.v1beta1.DataCatalog.RenameTagTemplateField].
  
  
  Attributes:
      name:
          Required. The name of the tag template. Example:  -  projects/
          {project_id}/locations/{location}/tagTemplates/{tag_template_i
          d}/fields/{tag_template_field_id}
      new_tag_template_field_id:
          Required. The new ID of this tag template field. For example,
          ``my_new_field``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.RenameTagTemplateFieldRequest)
    },
)
_sym_db.RegisterMessage(RenameTagTemplateFieldRequest)

DeleteTagTemplateFieldRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteTagTemplateFieldRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETETAGTEMPLATEFIELDREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Request message for
  [DeleteTagTemplateField][google.cloud.datacatalog.v1beta1.DataCatalog.DeleteTagTemplateField].
  
  
  Attributes:
      name:
          Required. The name of the tag template field to delete.
          Example:  -  projects/{project_id}/locations/{location}/tagTem
          plates/{tag_template_id}/fields/{tag_template_field_id}
      force:
          Required. Currently, this field must always be set to
          ``true``. This confirms the deletion of this field from any
          tags using this field. ``force = false`` will be supported in
          the future.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.DeleteTagTemplateFieldRequest)
    },
)
_sym_db.RegisterMessage(DeleteTagTemplateFieldRequest)

ListTagsRequest = _reflection.GeneratedProtocolMessageType(
    "ListTagsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTTAGSREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Request message for
  [ListTags][google.cloud.datacatalog.v1beta1.DataCatalog.ListTags].
  
  
  Attributes:
      parent:
          Required. The name of the Data Catalog resource to list the
          tags of. The resource could be an
          [Entry][google.cloud.datacatalog.v1beta1.Entry] or an
          [EntryGroup][google.cloud.datacatalog.v1beta1.EntryGroup].
          Examples:  -  projects/{project_id}/locations/{location}/entry
          Groups/{entry_group_id} -  projects/{project_id}/locations/{lo
          cation}/entryGroups/{entry_group_id}/entries/{entry_id}
      page_size:
          The maximum number of tags to return. Default is 10. Max limit
          is 1000.
      page_token:
          Token that specifies which page is requested. If empty, the
          first page is returned.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.ListTagsRequest)
    },
)
_sym_db.RegisterMessage(ListTagsRequest)

ListTagsResponse = _reflection.GeneratedProtocolMessageType(
    "ListTagsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTTAGSRESPONSE,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Response message for
  [ListTags][google.cloud.datacatalog.v1beta1.DataCatalog.ListTags].
  
  
  Attributes:
      tags:
          [Tag][google.cloud.datacatalog.v1beta1.Tag] details.
      next_page_token:
          Token to retrieve the next page of results. It is set to empty
          if no items remain in results.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.ListTagsResponse)
    },
)
_sym_db.RegisterMessage(ListTagsResponse)

ListEntriesRequest = _reflection.GeneratedProtocolMessageType(
    "ListEntriesRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTENTRIESREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Request message for
  [ListEntries][google.cloud.datacatalog.v1beta1.DataCatalog.ListEntries].
  
  
  Attributes:
      parent:
          Required. The name of the entry group that contains the
          entries, which can be provided in URL format. Example:  -  pro
          jects/{project_id}/locations/{location}/entryGroups/{entry_gro
          up_id}
      page_size:
          The maximum number of items to return. Default is 10. Max
          limit is 1000. Throws an invalid argument for ``page_size >
          1000``.
      page_token:
          Token that specifies which page is requested. If empty, the
          first page is returned.
      read_mask:
          The fields to return for each Entry. If not set or empty, all
          fields are returned. For example, setting read_mask to contain
          only one path “name” will cause ListEntries to return a list
          of Entries with only “name” field.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.ListEntriesRequest)
    },
)
_sym_db.RegisterMessage(ListEntriesRequest)

ListEntriesResponse = _reflection.GeneratedProtocolMessageType(
    "ListEntriesResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTENTRIESRESPONSE,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.datacatalog_pb2",
        "__doc__": """Response message for
  [ListEntries][google.cloud.datacatalog.v1beta1.DataCatalog.ListEntries].
  
  
  Attributes:
      entries:
          Entry details.
      next_page_token:
          Token to retrieve the next page of results. It is set to empty
          if no items remain in results.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.ListEntriesResponse)
    },
)
_sym_db.RegisterMessage(ListEntriesResponse)


DESCRIPTOR._options = None
_SEARCHCATALOGREQUEST.fields_by_name["scope"]._options = None
_SEARCHCATALOGREQUEST.fields_by_name["query"]._options = None
_SEARCHCATALOGREQUEST.fields_by_name["page_token"]._options = None
_CREATEENTRYGROUPREQUEST.fields_by_name["parent"]._options = None
_CREATEENTRYGROUPREQUEST.fields_by_name["entry_group_id"]._options = None
_UPDATEENTRYGROUPREQUEST.fields_by_name["entry_group"]._options = None
_GETENTRYGROUPREQUEST.fields_by_name["name"]._options = None
_DELETEENTRYGROUPREQUEST.fields_by_name["name"]._options = None
_DELETEENTRYGROUPREQUEST.fields_by_name["force"]._options = None
_LISTENTRYGROUPSREQUEST.fields_by_name["parent"]._options = None
_LISTENTRYGROUPSREQUEST.fields_by_name["page_size"]._options = None
_LISTENTRYGROUPSREQUEST.fields_by_name["page_token"]._options = None
_CREATEENTRYREQUEST.fields_by_name["parent"]._options = None
_CREATEENTRYREQUEST.fields_by_name["entry_id"]._options = None
_CREATEENTRYREQUEST.fields_by_name["entry"]._options = None
_UPDATEENTRYREQUEST.fields_by_name["entry"]._options = None
_DELETEENTRYREQUEST.fields_by_name["name"]._options = None
_GETENTRYREQUEST.fields_by_name["name"]._options = None
_ENTRY.fields_by_name["name"]._options = None
_ENTRY.fields_by_name["integrated_system"]._options = None
_ENTRY.fields_by_name["source_system_timestamps"]._options = None
_ENTRY._options = None
_ENTRYGROUP.fields_by_name["data_catalog_timestamps"]._options = None
_ENTRYGROUP._options = None
_CREATETAGTEMPLATEREQUEST.fields_by_name["parent"]._options = None
_CREATETAGTEMPLATEREQUEST.fields_by_name["tag_template_id"]._options = None
_CREATETAGTEMPLATEREQUEST.fields_by_name["tag_template"]._options = None
_GETTAGTEMPLATEREQUEST.fields_by_name["name"]._options = None
_UPDATETAGTEMPLATEREQUEST.fields_by_name["tag_template"]._options = None
_DELETETAGTEMPLATEREQUEST.fields_by_name["name"]._options = None
_DELETETAGTEMPLATEREQUEST.fields_by_name["force"]._options = None
_CREATETAGREQUEST.fields_by_name["parent"]._options = None
_CREATETAGREQUEST.fields_by_name["tag"]._options = None
_UPDATETAGREQUEST.fields_by_name["tag"]._options = None
_DELETETAGREQUEST.fields_by_name["name"]._options = None
_CREATETAGTEMPLATEFIELDREQUEST.fields_by_name["parent"]._options = None
_CREATETAGTEMPLATEFIELDREQUEST.fields_by_name["tag_template_field_id"]._options = None
_CREATETAGTEMPLATEFIELDREQUEST.fields_by_name["tag_template_field"]._options = None
_UPDATETAGTEMPLATEFIELDREQUEST.fields_by_name["name"]._options = None
_UPDATETAGTEMPLATEFIELDREQUEST.fields_by_name["tag_template_field"]._options = None
_UPDATETAGTEMPLATEFIELDREQUEST.fields_by_name["update_mask"]._options = None
_RENAMETAGTEMPLATEFIELDREQUEST.fields_by_name["name"]._options = None
_RENAMETAGTEMPLATEFIELDREQUEST.fields_by_name[
    "new_tag_template_field_id"
]._options = None
_DELETETAGTEMPLATEFIELDREQUEST.fields_by_name["name"]._options = None
_DELETETAGTEMPLATEFIELDREQUEST.fields_by_name["force"]._options = None
_LISTTAGSREQUEST.fields_by_name["parent"]._options = None
_LISTENTRIESREQUEST.fields_by_name["parent"]._options = None

_DATACATALOG = _descriptor.ServiceDescriptor(
    name="DataCatalog",
    full_name="google.cloud.datacatalog.v1beta1.DataCatalog",
    file=DESCRIPTOR,
    index=0,
    serialized_options=b"\312A\032datacatalog.googleapis.com\322A.https://www.googleapis.com/auth/cloud-platform",
    serialized_start=5881,
    serialized_end=12341,
    methods=[
        _descriptor.MethodDescriptor(
            name="SearchCatalog",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.SearchCatalog",
            index=0,
            containing_service=None,
            input_type=_SEARCHCATALOGREQUEST,
            output_type=_SEARCHCATALOGRESPONSE,
            serialized_options=b'\202\323\344\223\002\034"\027/v1beta1/catalog:search:\001*\332A\013scope,query',
        ),
        _descriptor.MethodDescriptor(
            name="CreateEntryGroup",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.CreateEntryGroup",
            index=1,
            containing_service=None,
            input_type=_CREATEENTRYGROUPREQUEST,
            output_type=_ENTRYGROUP,
            serialized_options=b'\202\323\344\223\002C"4/v1beta1/{parent=projects/*/locations/*}/entryGroups:\013entry_group\332A!parent,entry_group_id,entry_group',
        ),
        _descriptor.MethodDescriptor(
            name="UpdateEntryGroup",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.UpdateEntryGroup",
            index=2,
            containing_service=None,
            input_type=_UPDATEENTRYGROUPREQUEST,
            output_type=_ENTRYGROUP,
            serialized_options=b"\202\323\344\223\002O2@/v1beta1/{entry_group.name=projects/*/locations/*/entryGroups/*}:\013entry_group\332A\013entry_group\332A\027entry_group,update_mask",
        ),
        _descriptor.MethodDescriptor(
            name="GetEntryGroup",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.GetEntryGroup",
            index=3,
            containing_service=None,
            input_type=_GETENTRYGROUPREQUEST,
            output_type=_ENTRYGROUP,
            serialized_options=b"\202\323\344\223\0026\0224/v1beta1/{name=projects/*/locations/*/entryGroups/*}\332A\004name\332A\016name,read_mask",
        ),
        _descriptor.MethodDescriptor(
            name="DeleteEntryGroup",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.DeleteEntryGroup",
            index=4,
            containing_service=None,
            input_type=_DELETEENTRYGROUPREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\0026*4/v1beta1/{name=projects/*/locations/*/entryGroups/*}\332A\004name",
        ),
        _descriptor.MethodDescriptor(
            name="ListEntryGroups",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.ListEntryGroups",
            index=5,
            containing_service=None,
            input_type=_LISTENTRYGROUPSREQUEST,
            output_type=_LISTENTRYGROUPSRESPONSE,
            serialized_options=b"\202\323\344\223\0026\0224/v1beta1/{parent=projects/*/locations/*}/entryGroups\332A\006parent",
        ),
        _descriptor.MethodDescriptor(
            name="CreateEntry",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.CreateEntry",
            index=6,
            containing_service=None,
            input_type=_CREATEENTRYREQUEST,
            output_type=_ENTRY,
            serialized_options=b'\202\323\344\223\002G">/v1beta1/{parent=projects/*/locations/*/entryGroups/*}/entries:\005entry\332A\025parent,entry_id,entry',
        ),
        _descriptor.MethodDescriptor(
            name="UpdateEntry",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.UpdateEntry",
            index=7,
            containing_service=None,
            input_type=_UPDATEENTRYREQUEST,
            output_type=_ENTRY,
            serialized_options=b"\202\323\344\223\002M2D/v1beta1/{entry.name=projects/*/locations/*/entryGroups/*/entries/*}:\005entry\332A\005entry\332A\021entry,update_mask",
        ),
        _descriptor.MethodDescriptor(
            name="DeleteEntry",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.DeleteEntry",
            index=8,
            containing_service=None,
            input_type=_DELETEENTRYREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\002@*>/v1beta1/{name=projects/*/locations/*/entryGroups/*/entries/*}\332A\004name",
        ),
        _descriptor.MethodDescriptor(
            name="GetEntry",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.GetEntry",
            index=9,
            containing_service=None,
            input_type=_GETENTRYREQUEST,
            output_type=_ENTRY,
            serialized_options=b"\202\323\344\223\002@\022>/v1beta1/{name=projects/*/locations/*/entryGroups/*/entries/*}\332A\004name",
        ),
        _descriptor.MethodDescriptor(
            name="LookupEntry",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.LookupEntry",
            index=10,
            containing_service=None,
            input_type=_LOOKUPENTRYREQUEST,
            output_type=_ENTRY,
            serialized_options=b"\202\323\344\223\002\031\022\027/v1beta1/entries:lookup",
        ),
        _descriptor.MethodDescriptor(
            name="ListEntries",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.ListEntries",
            index=11,
            containing_service=None,
            input_type=_LISTENTRIESREQUEST,
            output_type=_LISTENTRIESRESPONSE,
            serialized_options=b"\202\323\344\223\002@\022>/v1beta1/{parent=projects/*/locations/*/entryGroups/*}/entries\332A\006parent",
        ),
        _descriptor.MethodDescriptor(
            name="CreateTagTemplate",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.CreateTagTemplate",
            index=12,
            containing_service=None,
            input_type=_CREATETAGTEMPLATEREQUEST,
            output_type=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAGTEMPLATE,
            serialized_options=b'\202\323\344\223\002E"5/v1beta1/{parent=projects/*/locations/*}/tagTemplates:\014tag_template\332A#parent,tag_template_id,tag_template',
        ),
        _descriptor.MethodDescriptor(
            name="GetTagTemplate",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.GetTagTemplate",
            index=13,
            containing_service=None,
            input_type=_GETTAGTEMPLATEREQUEST,
            output_type=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAGTEMPLATE,
            serialized_options=b"\202\323\344\223\0027\0225/v1beta1/{name=projects/*/locations/*/tagTemplates/*}\332A\004name",
        ),
        _descriptor.MethodDescriptor(
            name="UpdateTagTemplate",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.UpdateTagTemplate",
            index=14,
            containing_service=None,
            input_type=_UPDATETAGTEMPLATEREQUEST,
            output_type=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAGTEMPLATE,
            serialized_options=b"\202\323\344\223\002R2B/v1beta1/{tag_template.name=projects/*/locations/*/tagTemplates/*}:\014tag_template\332A\014tag_template\332A\030tag_template,update_mask",
        ),
        _descriptor.MethodDescriptor(
            name="DeleteTagTemplate",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.DeleteTagTemplate",
            index=15,
            containing_service=None,
            input_type=_DELETETAGTEMPLATEREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\0027*5/v1beta1/{name=projects/*/locations/*/tagTemplates/*}\332A\nname,force",
        ),
        _descriptor.MethodDescriptor(
            name="CreateTagTemplateField",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.CreateTagTemplateField",
            index=16,
            containing_service=None,
            input_type=_CREATETAGTEMPLATEFIELDREQUEST,
            output_type=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAGTEMPLATEFIELD,
            serialized_options=b'\202\323\344\223\002T">/v1beta1/{parent=projects/*/locations/*/tagTemplates/*}/fields:\022tag_template_field\332A/parent,tag_template_field_id,tag_template_field',
        ),
        _descriptor.MethodDescriptor(
            name="UpdateTagTemplateField",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.UpdateTagTemplateField",
            index=17,
            containing_service=None,
            input_type=_UPDATETAGTEMPLATEFIELDREQUEST,
            output_type=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAGTEMPLATEFIELD,
            serialized_options=b"\202\323\344\223\002T2>/v1beta1/{name=projects/*/locations/*/tagTemplates/*/fields/*}:\022tag_template_field\332A\027name,tag_template_field\332A#name,tag_template_field,update_mask",
        ),
        _descriptor.MethodDescriptor(
            name="RenameTagTemplateField",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.RenameTagTemplateField",
            index=18,
            containing_service=None,
            input_type=_RENAMETAGTEMPLATEFIELDREQUEST,
            output_type=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAGTEMPLATEFIELD,
            serialized_options=b'\202\323\344\223\002J"E/v1beta1/{name=projects/*/locations/*/tagTemplates/*/fields/*}:rename:\001*\332A\036name,new_tag_template_field_id',
        ),
        _descriptor.MethodDescriptor(
            name="DeleteTagTemplateField",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.DeleteTagTemplateField",
            index=19,
            containing_service=None,
            input_type=_DELETETAGTEMPLATEFIELDREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\002@*>/v1beta1/{name=projects/*/locations/*/tagTemplates/*/fields/*}\332A\nname,force",
        ),
        _descriptor.MethodDescriptor(
            name="CreateTag",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.CreateTag",
            index=20,
            containing_service=None,
            input_type=_CREATETAGREQUEST,
            output_type=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAG,
            serialized_options=b'\202\323\344\223\002\220\001"E/v1beta1/{parent=projects/*/locations/*/entryGroups/*/entries/*}/tags:\003tagZB";/v1beta1/{parent=projects/*/locations/*/entryGroups/*}/tags:\003tag\332A\nparent,tag',
        ),
        _descriptor.MethodDescriptor(
            name="UpdateTag",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.UpdateTag",
            index=21,
            containing_service=None,
            input_type=_UPDATETAGREQUEST,
            output_type=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2._TAG,
            serialized_options=b"\202\323\344\223\002\230\0012I/v1beta1/{tag.name=projects/*/locations/*/entryGroups/*/entries/*/tags/*}:\003tagZF2?/v1beta1/{tag.name=projects/*/locations/*/entryGroups/*/tags/*}:\003tag\332A\003tag\332A\017tag,update_mask",
        ),
        _descriptor.MethodDescriptor(
            name="DeleteTag",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.DeleteTag",
            index=22,
            containing_service=None,
            input_type=_DELETETAGREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\002\206\001*E/v1beta1/{name=projects/*/locations/*/entryGroups/*/entries/*/tags/*}Z=*;/v1beta1/{name=projects/*/locations/*/entryGroups/*/tags/*}\332A\004name",
        ),
        _descriptor.MethodDescriptor(
            name="ListTags",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.ListTags",
            index=23,
            containing_service=None,
            input_type=_LISTTAGSREQUEST,
            output_type=_LISTTAGSRESPONSE,
            serialized_options=b"\202\323\344\223\002\206\001\022E/v1beta1/{parent=projects/*/locations/*/entryGroups/*/entries/*}/tagsZ=\022;/v1beta1/{parent=projects/*/locations/*/entryGroups/*}/tags\332A\006parent",
        ),
        _descriptor.MethodDescriptor(
            name="SetIamPolicy",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.SetIamPolicy",
            index=24,
            containing_service=None,
            input_type=google_dot_iam_dot_v1_dot_iam__policy__pb2._SETIAMPOLICYREQUEST,
            output_type=google_dot_iam_dot_v1_dot_policy__pb2._POLICY,
            serialized_options=b'\202\323\344\223\002\227\001"F/v1beta1/{resource=projects/*/locations/*/tagTemplates/*}:setIamPolicy:\001*ZJ"E/v1beta1/{resource=projects/*/locations/*/entryGroups/*}:setIamPolicy:\001*\332A\017resource,policy',
        ),
        _descriptor.MethodDescriptor(
            name="GetIamPolicy",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.GetIamPolicy",
            index=25,
            containing_service=None,
            input_type=google_dot_iam_dot_v1_dot_iam__policy__pb2._GETIAMPOLICYREQUEST,
            output_type=google_dot_iam_dot_v1_dot_policy__pb2._POLICY,
            serialized_options=b'\202\323\344\223\002\355\001"F/v1beta1/{resource=projects/*/locations/*/tagTemplates/*}:getIamPolicy:\001*ZJ"E/v1beta1/{resource=projects/*/locations/*/entryGroups/*}:getIamPolicy:\001*ZT"O/v1beta1/{resource=projects/*/locations/*/entryGroups/*/entries/*}:getIamPolicy:\001*\332A\010resource',
        ),
        _descriptor.MethodDescriptor(
            name="TestIamPermissions",
            full_name="google.cloud.datacatalog.v1beta1.DataCatalog.TestIamPermissions",
            index=26,
            containing_service=None,
            input_type=google_dot_iam_dot_v1_dot_iam__policy__pb2._TESTIAMPERMISSIONSREQUEST,
            output_type=google_dot_iam_dot_v1_dot_iam__policy__pb2._TESTIAMPERMISSIONSRESPONSE,
            serialized_options=b'\202\323\344\223\002\377\001"L/v1beta1/{resource=projects/*/locations/*/tagTemplates/*}:testIamPermissions:\001*ZP"K/v1beta1/{resource=projects/*/locations/*/entryGroups/*}:testIamPermissions:\001*ZZ"U/v1beta1/{resource=projects/*/locations/*/entryGroups/*/entries/*}:testIamPermissions:\001*',
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_DATACATALOG)

DESCRIPTOR.services_by_name["DataCatalog"] = _DATACATALOG

# @@protoc_insertion_point(module_scope)
